import java.util.Hashtable;
import java.util.Set;

import org.gdal.gdal.Dataset;
import org.gdal.gdal.gdal;
import org.gdal.gdalconst.gdalconstConstants;
import org.gdal.osr.CoordinateTransformation;
import org.gdal.osr.SpatialReference;

public class GDALTest {

	/**
	 * @param args
	 */
	public static void main(String[] args) {

		GDALTest t = new GDALTest();
		t.run(args);

	}

	private void run(String[] args) {
		gdal.AllRegister();
		String fileName = args[0];
		Dataset ds = gdal.Open(fileName, gdalconstConstants.GA_ReadOnly);

		if (ds != null) {
			System.out.println("Description =" + ds.GetDescription());
			String cs = ds.GetProjection();
			System.out.println("projection = " + ds.GetProjection());

			double[] geoTransform = ds.GetGeoTransform();
			System.out.println("pixel width x = " + geoTransform[1]);
			System.out.println("pixel width y = " + geoTransform[5]);
			System.out.println("ULX = " + geoTransform[0]);
			System.out.println("ULY = " + geoTransform[3]);

			System.out
					.println("LRX = "
							+ (geoTransform[0] + geoTransform[1]
									* ds.getRasterXSize() + geoTransform[2]
									* ds.getRasterYSize()));
			System.out
					.println("LRY = "
							+ (geoTransform[3] + geoTransform[4]
									* ds.getRasterXSize() + geoTransform[5]
									* ds.getRasterYSize()));

			System.out.println("Rows = " + ds.getRasterXSize());
			System.out.println("Cols = " + ds.getRasterYSize());

			Hashtable ht = ds.GetMetadata_Dict();
			Set<String> en = ht.keySet();
			for (String s : en) {
				System.out.println("Metadata = " + s + " : " + ht.get(s));
			}

			SpatialReference sr = new SpatialReference();
			sr.ImportFromWkt(cs);

			System.out.println(sr.ExportToPrettyWkt());
			System.out.println("Is geographic "
					+ (sr.IsGeographic() == 1 ? "Yes" : "No"));
			System.out.println("Is projected "
					+ (sr.IsProjected() == 1 ? "Yes" : "No"));
			System.out.println("linear units = " + sr.GetLinearUnits() + " "
					+ sr.GetLinearUnitsName());

			int epsg = 0;
			try {
				epsg = sr.AutoIdentifyEPSG();

			} catch (Exception w) {
				System.err.println(w.getMessage());
			}
			System.out.println("epsg auto = " + epsg);

			SpatialReference sr0 = new SpatialReference();
			sr0.ImportFromEPSG(4283);
			System.out.println("srs = " + sr0.ExportToPrettyWkt());
			CoordinateTransformation ct = new CoordinateTransformation(sr, sr0);

			System.out.println("4283 Is geographic "
					+ (sr0.IsGeographic() == 1 ? "Yes" : "No"));
			System.out.println("4283 Is projected "
					+ (sr0.IsProjected() == 1 ? "Yes" : "No"));

			SpatialReference sr1 = new SpatialReference();
			sr1.ImportFromEPSG(3112);
			System.out.println("srs = " + sr1.ExportToPrettyWkt());
			System.out.println("3112 Is geographic "
					+ (sr1.IsGeographic() == 1 ? "Yes" : "No"));
			System.out.println("3112 Is projected "
					+ (sr1.IsProjected() == 1 ? "Yes" : "No"));
		}
//		gdal.GDALDestroyDriverManager();
	}
}
