//============================================================================
// Name        : pointillise.cpp
// Author      : VPAC
// Version     :
// Copyright   : 
// Description : get info from raster
//============================================================================

#include <iostream>
#include "gdal_priv.h"
#include "exceptions.h"

namespace VPAC {

/**
 * Get info from raster.
 */
class GetInfoTest {
protected:
	GDALDataset *input;

public:
	std::string inputFileName;
	std::string outputFileName;

public:

	GetInfoTest() :
	input(NULL)
	{
	}

	~GetInfoTest() throw() {
		if (input != NULL) {
			//GDALClose(input);
			//input = NULL;
		}
	}

	void run() {
		openDatasets();
	}

protected:

	void openDatasets() throw (MyException) {
		if (input != NULL) {
			throw MyException("Datasets are already open!");
		}

	    	input = (GDALDataset *) GDALOpen(inputFileName.c_str(), GA_ReadOnly);
	    	if (input == NULL) {
	    		throw RequestException("Could not open source file.");
	    	}
    	    	GDALDriverH   hDriver;

	    	hDriver = GDALGetDatasetDriver( input );
            	printf( "Driver: %s/%s\n",
            	GDALGetDriverShortName( hDriver ),
            	GDALGetDriverLongName( hDriver ) );

    	    	printf( "Size is %dx%dx%d\n",
            		GDALGetRasterXSize( input ), 
            		GDALGetRasterYSize( input ),
            		GDALGetRasterCount( input ) );
	}
}; // class GetInfoTest

} // namespace VPAC

using namespace VPAC;

int main(int argc, char *argv[]) {
	try {
		GetInfoTest getinfo;
		GDALAllRegister();

		if (argc != 2) {
			throw RequestException("Invalid arguments.");
		}

		getinfo.inputFileName = argv[1];
		getinfo.run();

	} catch (RequestException e) {
		std::cerr << "Error: " << e.what() << std::endl;
		std::cerr << "Usage: getinfo <input file>" <<
				std::endl;
	} catch (MyException e) {
		std::cerr << "Error: " << e.what() << std::endl;
	}
    return 0;
}
